@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Shipwright::Util;
 
-use base qw/App::CLI::Command Class::Accessor::Fast Shipwright::Script/;
+use base qw/App::CLI::Command Shipwright::Base Shipwright::Script/;
 
 use Shipwright;
 
